@@ -1,4 +1,6 @@
-use crypto_markets::{fetch_markets, fetch_symbols, get_market_types, MarketType};
+use crypto_market_type::{get_market_types, MarketType};
+use crypto_markets::{fetch_markets, fetch_symbols};
+use crypto_pair::get_market_type;
 use test_case::test_case;
 
 #[macro_use]
@@ -17,6 +19,10 @@ fn fetch_spot_symbols() {
     assert!(!symbols.is_empty());
     for symbol in symbols.iter() {
         assert!(symbol.starts_with('t'));
+        assert_eq!(
+            MarketType::Spot,
+            get_market_type(&symbol, EXCHANGE_NAME, None)
+        );
     }
 }
 
@@ -26,7 +32,15 @@ fn fetch_linear_swap_symbols() {
     assert!(!symbols.is_empty());
     for symbol in symbols.iter() {
         assert!(symbol.starts_with('t'));
-        assert!(symbol.ends_with("F0:USTF0") || symbol.ends_with("F0:BTCF0"));
+        assert!(
+            symbol.ends_with("F0:USTF0")
+                || symbol.ends_with("F0:BTCF0")
+                || symbol.ends_with("F0:EUTF0")
+        );
+        assert_eq!(
+            MarketType::LinearSwap,
+            get_market_type(&symbol, EXCHANGE_NAME, None)
+        );
     }
 }
 
