@@ -1,4 +1,6 @@
-use crypto_markets::{fetch_markets, fetch_symbols, get_market_types, MarketType};
+use crypto_market_type::{get_market_types, MarketType};
+use crypto_markets::{fetch_markets, fetch_symbols};
+use crypto_pair::get_market_type;
 use test_case::test_case;
 
 #[macro_use]
@@ -6,31 +8,6 @@ mod utils;
 
 const EXCHANGE_NAME: &str = "bitmex";
 
-fn get_market_type_from_symbol(symbol: &str) -> MarketType {
-    let date = &symbol[(symbol.len() - 2)..];
-    if date.parse::<i64>().is_ok() {
-        // future
-        if symbol.starts_with("XBT") {
-            // Settled in XBT, quoted in USD
-            MarketType::InverseFuture
-        } else if (&symbol[..(symbol.len() - 3)]).ends_with("USD") {
-            // Settled in XBT, quoted in USD
-            MarketType::QuantoFuture
-        } else {
-            // Settled in XBT, quoted in XBT
-            MarketType::LinearFuture
-        }
-    } else {
-        // swap
-        if symbol.starts_with("XBT") {
-            // Settled in XBT, quoted in USD
-            MarketType::InverseSwap
-        } else {
-            MarketType::QuantoSwap
-        }
-    }
-}
-
 #[test]
 fn fetch_all_symbols() {
     gen_all_symbols!();
@@ -49,7 +26,23 @@ fn fetch_inverse_swap_symbols() {
     for symbol in symbols.iter() {
         assert!(symbol.starts_with("XBT"));
         assert!(symbol.ends_with("USD") || symbol.ends_with("EUR"));
-        assert_eq!(MarketType::InverseSwap, get_market_type_from_symbol(symbol));
+        assert_eq!(
+            MarketType::InverseSwap,
+            get_market_type(symbol, EXCHANGE_NAME, None)
+        );
+    }
+}
+
+#[test]
+fn fetch_linear_swap_symbols() {
+    let symbols = fetch_symbols(EXCHANGE_NAME, MarketType::LinearSwap).unwrap();
+    assert!(!symbols.is_empty());
+    for symbol in symbols.iter() {
+        assert!(symbol.ends_with("USDT"));
+        assert_eq!(
+            MarketType::LinearSwap,
+            get_market_type(symbol, EXCHANGE_NAME, None)
+        );
     }
 }
 
@@ -59,7 +52,10 @@ fn fetch_quanto_swap_symbols() {
     assert!(!symbols.is_empty());
     for symbol in symbols.iter() {
         assert!(symbol.ends_with("USD") || symbol.ends_with("USDT"));
-        assert_eq!(MarketType::QuantoSwap, get_market_type_from_symbol(symbol));
+        assert_eq!(
+            MarketType::QuantoSwap,
+            get_market_type(symbol, EXCHANGE_NAME, None)
+        );
     }
 }
 
@@ -73,7 +69,7 @@ fn fetch_inverse_future_symbols() {
         assert!(date.parse::<i64>().is_ok());
         assert_eq!(
             MarketType::InverseFuture,
-            get_market_type_from_symbol(symbol)
+            get_market_type(symbol, EXCHANGE_NAME, None)
         );
     }
 }
@@ -95,7 +91,7 @@ fn fetch_quanto_future_symbols() {
         assert!(quote == "USD" || quote == "USDT");
         assert_eq!(
             MarketType::QuantoFuture,
-            get_market_type_from_symbol(symbol)
+            get_market_type(symbol, EXCHANGE_NAME, None)
         );
     }
 }
@@ -109,7 +105,7 @@ fn fetch_linear_future_symbols() {
         assert!(date.parse::<i64>().is_ok());
         assert_eq!(
             MarketType::LinearFuture,
-            get_market_type_from_symbol(symbol)
+            get_market_type(symbol, EXCHANGE_NAME, None)
         );
     }
 }
